@@ -28,8 +28,13 @@ module Nokogiri
 
       # issue #1005
       def test_strict_parsing_empty_doc_should_raise_exception
-        assert_raises(SyntaxError) do
-          Nokogiri::XML(StringIO.new('')) { |c| c.strict }
+        ["", " "].each do |empty_string|
+          assert_raises(SyntaxError, "empty string '#{empty_string}' should raise a SyntaxError") do
+            Nokogiri::XML(empty_string) { |c| c.strict }
+          end
+          assert_raises(SyntaxError, "StringIO of '#{empty_string}' should raise a SyntaxError") do
+            Nokogiri::XML(StringIO.new(empty_string)) { |c| c.strict }
+          end
         end
       end
 
@@ -216,7 +221,7 @@ module Nokogiri
       end
 
       def test_pp
-        out = StringIO.new('')
+        out = StringIO.new(String.new)
         ::PP.pp @xml, out
         assert_operator out.string.length, :>, 0
       end
@@ -689,6 +694,17 @@ module Nokogiri
         refute_nil doc
       end
 
+      def test_parse_works_with_an_object_that_responds_to_read
+        klass = Class.new do
+          def read *args
+            "<div>foo</div>"
+          end
+        end
+
+        doc = Nokogiri::XML.parse klass.new
+        doc.at_css("div").content.must_equal("foo")
+      end
+
       def test_search_on_empty_documents
         doc = Nokogiri::XML::Document.new
         ns = doc.search('//foo')
